@@ -1,5 +1,5 @@
 package Log::Contextual;
-$Log::Contextual::VERSION = '0.007001';
+$Log::Contextual::VERSION = '0.008000';
 # ABSTRACT: Simple logging interface with a contextual log
 
 use strict;
@@ -33,7 +33,9 @@ my @log = ((map "log_$_", @levels), (map "logS_$_", @levels));
 sub _maybe_export {
    my ($spec, $target, $name, $new_code) = @_;
 
-   if (my $code = $target->can($name)) {
+   no strict 'refs';
+   if (defined &{"${target}::${name}"}) {
+      my $code = \&{"${target}::${name}"};
 
       # this will warn
       $spec->add_export("&$name", $new_code)
@@ -145,6 +147,18 @@ sub before_import {
             return @args;
          };
       }
+      if ($spec->config->{log} || $exports->{"&slog_$level"}) {
+         $exports{slog_} = sub {
+            my ($text, @args) = @_;
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_text   => $text,
+               message_args   => \@args,
+            );
+            return @args;
+         };
+      }
       if ($spec->config->{log} || $exports->{"&logS_$level"}) {
          $exports{logS_} = sub (&@) {
             my ($code, @args) = @_;
@@ -157,6 +171,18 @@ sub before_import {
             return $args[0];
          };
       }
+      if ($spec->config->{log} || $exports->{"&slogS_$level"}) {
+         $exports{slogS_} = sub {
+            my ($text, @args) = @_;
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_text   => $text,
+               message_args   => \@args,
+            );
+            return $args[0];
+         };
+      }
       if ($spec->config->{dlog} || $exports->{"&Dlog_$level"}) {
          $exports{Dlog_} = sub (&@) {
             my ($code, @args) = @_;
@@ -173,6 +199,21 @@ sub before_import {
             return @args;
          };
       }
+      if ($spec->config->{dlog} || $exports->{"&Dslog_$level"}) {
+         $exports{Dslog_} = sub {
+            my ($text, @args) = @_;
+            my $wrapped = sub {
+               $text . (@_ ? Data::Dumper::Concise::Dumper @_ : '()');
+            };
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $wrapped,
+               message_args   => \@args,
+            );
+            return @args;
+         };
+      }
       if ($spec->config->{dlog} || $exports->{"&DlogS_$level"}) {
          $exports{DlogS_} = sub (&$) {
             my ($code, $ref) = @_;
@@ -189,6 +230,21 @@ sub before_import {
             return $ref;
          };
       }
+      if ($spec->config->{dlog} || $exports->{"&DslogS_$level"}) {
+         $exports{DslogS_} = sub {
+            my ($text, $ref) = @_;
+            my $wrapped = sub {
+               $text . Data::Dumper::Concise::Dumper($_[0]);
+            };
+            $router->handle_log_request(
+               %base,
+               caller_package => scalar(caller),
+               message_sub    => $wrapped,
+               message_args   => [$ref],
+            );
+            return $ref;
+         };
+      }
       _maybe_export($spec, $importer, $_ . $level, $exports{$_})
         for keys %exports;
    }
@@ -228,7 +284,7 @@ Log::Contextual - Simple logging interface with a contextual log
 
 =head1 VERSION
 
-version 0.007001
+version 0.008000
 
 =head1 SYNOPSIS
 
@@ -255,7 +311,7 @@ version 0.007001
      log_trace { 'foo entered' };
      my ($foo, $bar) = Dlog_trace { "params for foo: $_" } @args;
      # ...
-     log_trace { 'foo left' };
+     slog_trace 'foo left';
    };
  }
 
@@ -284,7 +340,7 @@ Major benefits:
 
 =item * Efficient
 
-The logging functions take blocks, so if a log level is disabled, the
+The default logging functions take blocks, so if a log level is disabled, the
 block will not run:
 
  # the following won't run if debug is off
@@ -549,6 +605,14 @@ B<Note:> C<log_fatal> does not call C<die> for you, see L</EXCEPTIONS AND ERROR
 
 =back
 
+=head2 slog_$level
+
+Mostly the same as L</log_$level>, but expects a string as first argument,
+not a block. Arguments are passed through just the same, but since it's just a
+string, interpolation of arguments into it must be done manually.
+
+ my @friends = slog_trace 'friends list being generated.', generate_friend_list();
+
 =head2 logS_$level
 
 Import Tag: C<:log>
@@ -565,6 +629,14 @@ same:
 
 See also: L</DlogS_$level>.
 
+=head2 slogS_$level
+
+Mostly the same as L</logS_$level>, but expects a string as first argument,
+not a block. Arguments are passed through just the same, but since it's just a
+string, interpolation of arguments into it must be done manually.
+
+ my $friend = slogS_trace 'I only have one friend.', friend();
+
 =head2 Dlog_$level
 
 Import Tag: C<:dlog>
@@ -607,6 +679,15 @@ B<Note:> C<Dlog_fatal> does not call C<die> for you, see L</EXCEPTIONS AND ERROR
 
 =back
 
+=head2 Dslog_$level
+
+Mostly the same as L</Dlog_$level>, but expects a string as first argument,
+not a block. Arguments are passed through just the same, but since it's just a
+string, no interpolation point can be used, instead the Dumper output is
+appended.
+
+ my @nicks = Dslog_debug "names: ", map $_->value, $frew->names->all;
+
 =head2 DlogS_$level
 
 Import Tag: C<:dlog>
@@ -620,6 +701,16 @@ slurping up (and also setting C<wantarray>) all the C<@args>
  my $pals_rs = DlogS_debug { "pals resultset: $_" }
    $schema->resultset('Pals')->search({ perlers => 1 });
 
+=head2 DslogS_$level
+
+Mostly the same as L</DlogS_$level>, but expects a string as first argument,
+not a block. Arguments are passed through just the same, but since it's just a
+string, no interpolation point can be used, instead the Dumper output is
+appended.
+
+ my $pals_rs = DslogS_debug "pals resultset: ",
+   $schema->resultset('Pals')->search({ perlers => 1 });
+
 =head1 LOGGER CODEREF
 
 Anywhere a logger object can be passed, a coderef is accepted.  This is so
